@@ -178,13 +178,48 @@ class qimai_intside_tool:
         else:
             return 0
 
+# 常用的自定义参数；
+class qimai_diy_var:
+    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4):
+        self.country = country
+        self.rank_type = rank_type
+        self.version = version
+        self.device = device
+        self.search_type= search_type
+        self.brand = brand
+        self.day = day
+        self.appRankShow = appRankShow
+        self.subclass = subclass
+        self.simple = simple
+        self.rankEchartType = rankEchartType
+        self.rankType = rankType
+        self.run_time = run_time
+        self.one_day = datetime.timedelta(days=1)
+        self.status = status
+        self.keyword_hot_start = keyword_hot_start
+        self.typec = typec
+        self.star = star
+        self.delete = delete
+        self.orderType = orderType
+        self.commentType = commentType
+        self.clear_type = clear_type
+        self.status_type = status_type
+        self.genre_type = genre_type
+        self.search_word = search_word
+        self.filter = filter
+        self.export_type = export_type
+        self.sort_field = sort_field
+        self.sort_type = sort_type
+        self.option = option
+
 # 获取基础信息相关数据；
-class get_app_appinfo:
+class get_app_appinfo(qimai_diy_var):
     def __init__(self, appid):
+        qimai_diy_var.__init__(self)
         self.appid = appid
 
     def get_appinfo(self):
-        url = 'https://api.qimai.cn/app/appinfo?appid=%s&country=cn' %(self.appid)
+        url = 'https://api.qimai.cn/app/appinfo?appid=%s&country=%s' %(self.appid, self.country)
         res = session.get(url, headers=headers)
         self.appinfo = res.json()
         return self.appinfo
@@ -195,15 +230,15 @@ class get_app_appinfo:
         return self.subname
 
 # 获取榜单相关数据；
-class get_app_rank:
-    def __init__(self, appid, start_time, end_time, rank_type='all'):
+class get_app_rank(qimai_diy_var):
+    def __init__(self, appid, start_time, end_time):
+        qimai_diy_var.__init__(self)
         self.appid = appid
         self.start_time = start_time
         self.end_time = end_time
-        self.rank_type = rank_type
 
     def get_rank_info(self):
-        url = 'https://api.qimai.cn/app/rankMore?appid=%s&country=cn&brand=%s&day=1&appRankShow=1&subclass=all&simple=1&rankType=day&sdate=%s&edate=%s&rankEchartType=1' %(self.appid, self.rank_type, self.start_time, self.end_time)
+        url = 'https://api.qimai.cn/app/rankMore?appid=%s&country=%s&brand=%s&day=%s&appRankShow=%s&subclass=%s&simple=%s&sdate=%s&edate=%s&rankEchartType=%s&rankType=%s&device=%s' %(self.appid, self.country, self.brand, self.day, self.appRankShow, self.subclass, self.simple, self.start_time, self.end_time, self.rankEchartType, self.rankType, self.device)
         res = session.get(url, headers=headers)
         self.rank_info = res.json()
         return self.rank_info
@@ -224,9 +259,13 @@ class get_app_rank:
 
 
 # 获取开发商相关数据；
-class get_app_samePubApp(get_app_appinfo):
+class get_app_samePubApp(get_app_appinfo, qimai_diy_var):
+    def __init__(self, appid):
+        get_app_appinfo.__init__(self, appid)
+        qimai_diy_var.__init__(self)
+
     def get_samePubApp(self):
-        url = 'https://api.qimai.cn/app/samePubApp?appid=%s&country=cn' %(self.appid)
+        url = 'https://api.qimai.cn/app/samePubApp?appid=%s&country=%s' %(self.appid, self.country)
         res = session.get(url, headers=headers)
         self.samePubApp = res.json()['samePubApps']
         return self.samePubApp
@@ -240,24 +279,19 @@ class get_app_samePubApp(get_app_appinfo):
                 return self.app_total_genid, self.app_class_genid
 
 # 获取关键词的相关数据；
-class get_keyword_info:
-    def __init__(self, keyword, run_time=datetime.date.today(), version='ios12', country='cn', device='iphone', search_type='all'):
+class get_keyword_info(qimai_diy_var):
+    def __init__(self, keyword):
+        qimai_diy_var.__init__(self)
         self.keyword = keyword
-        self.run_time = run_time
-        self.version = version
-        self.country = country
-        self.device = device
-        self.search_type = search_type
-        self.one_day = datetime.timedelta(days=1)
 
     def get_keyword_search(self):
-        url = 'https://api.qimai.cn/search/index?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.run_time-self.one_day)
+        url = 'https://api.qimai.cn/search/getWordInfo?country=%s&device=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.country, self.device, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
         res = session.get(url, headers=headers)
         self.keyword_serch_index = res.json()
         return self.keyword_serch_index
 
     def get_keyword_WordInfo(self):
-        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.run_time-self.one_day)
+        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
         res = session.get(url, headers=headers)
         self.keyword_WordInfo = res.json()
         return self.keyword_WordInfo
@@ -268,28 +302,27 @@ class get_keyword_info:
         return self.hints
 
 # 获取产品的关键词相关数据；
-class get_app_keyword:
-    def __init__(self, appid, run_time):
+class get_app_keyword(qimai_diy_var):
+    def __init__(self, appid):
+        qimai_diy_var.__init__(self)
         self.appid = appid
-        self.run_time = run_time
 
     def get_keywordDetail(self):
-        url = 'https://api.qimai.cn/app/keywordDetail?country=cn&appid=%s&version=ios12&sdate=%s&edate=' %(self.appid, self.run_time)
+        url = 'https://api.qimai.cn/app/keywordDetail?country=%s&appid=%s&version=%s&sdate=%s&device=%s&edate=' %(self.country, self.appid, self.version, self.run_time, self.device)
         res = session.get(url, headers=headers)
         self.app_keywordDetail = res.json()
         return self.app_keywordDetail
 
     def get_keywordSummary(self):
-        url = 'https://api.qimai.cn/app/keywordSummary?country=cn&appid=%s&version=ios12&sdate=%s&edate=' %(self.appid, self.run_time)
+        url = 'https://api.qimai.cn/app/keywordSummary?country=%s&appid=%s&version=%s&sdate=%s&device=%s&edate=' %(self.country, self.appid, self.version, self.run_time, self.device)
         res = session.get(url, headers=headers)
         self.app_keywordSummary = res.json()
         return self.app_keywordSummary
 
-    def get_AnalysisDataKeyword(self, start_time, end_time, start_hot):
+    def get_AnalysisDataKeyword(self, start_time, end_time):
         self.start_time = start_time
         self.end_time = end_time
-        self.start_hot = start_hot
-        url = 'https://api.qimai.cn/account/getAnalysisDataKeyword?appid=%s&country=cn&device=iphone&sdate=%s&edate=%s&version=ios12&hints=%s' %(self.appid, self.start_time, self.end_time, self.start_hot)
+        url = 'https://api.qimai.cn/account/getAnalysisDataKeyword?appid=%s&country=%s&device=%s&sdate=%s&edate=%s&version=%s&hints=%s' %(self.appid, self.country, self.device, self.start_time, self.end_time, self.version, self.keyword_hot_start)
         res = session.get(url, headers=headers)
         self.app_AnalysisDataKeyword = res.json()
         return self.app_AnalysisDataKeyword
@@ -301,28 +334,27 @@ class get_app_keyword:
         return self.json_df
 
 # 获取产品评论的相关接口；
-class get_app_comment:
-    def __init__(self, appid, start_time, end_time, typec='day', star='five'):
+class get_app_comment(qimai_diy_var):
+    def __init__(self, appid, start_time, end_time):
+        qimai_diy_var.__init__(self)
         self.appid = appid
         self.start_time = start_time
         self.end_time = end_time
-        self.typec = typec
-        self.star = star
 
     def get_commentRateNum(self):
-        url = 'https://api.qimai.cn/app/commentRateNum?appid=%s&country=cn&sdate=%s&edate=%s&typec=%s' %(self.appid, self.start_time, self.end_time, self.typec)
+        url = 'https://api.qimai.cn/app/commentRateNum?appid=%s&country=%s&sdate=%s&edate=%s&typec=%s' %(self.appid, self.country, self.start_time, self.end_time, self.typec)
         res = session.get(url, headers=headers)
         self.app_commentRateNum = res.json()
         return self.app_commentRateNum
 
     def get_commentNum(self):
-        url = 'https://api.qimai.cn/app/commentNum?appid=%s&country=cn&delete=-1&sdate=%s&edate=%s' %(self.appid, self.start_time, self.end_time)
+        url = 'https://api.qimai.cn/app/commentNum?appid=%s&country=%s&delete=%s&sdate=%s&edate=%s' %(self.appid, self.country, self.delete, self.start_time, self.end_time)
         res = session.get(url, headers=headers)
         self.app_commentNum = res.json()
         return self.app_commentNum
 
     def get_comment(self):
-        url = 'https://api.qimai.cn/app/comment?appid=%s&country=cn&sword=&sdate=%s+00:00:00&edate=%s+23:59:59&star=five&orderType=time' %(self.appid, self.start_time, self.end_time)
+        url = 'https://api.qimai.cn/app/comment?appid=%s&country=%s&sword=&sdate=%s+00:00:00&edate=%s+23:59:59&orderType=%s&commentType=%s' %(self.appid, self.country, self.start_time, self.end_time, self.orderType, self.commentType)
         res = session.get(url, headers=headers)
         self.app_comment = res.json()
         return self.app_comment
@@ -351,13 +383,11 @@ class get_app_comment:
         return df
 
 # 获取清榜列表相关数据；
-class get_clear_rank_list:
-    def __init__(self, start_time, end_time, genre_type=36, status_type=3, clear_type=1):
+class get_clear_rank_list(qimai_diy_var):
+    def __init__(self, start_time, end_time):
+        qimai_diy_var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
-        self.genre_type = genre_type
-        self.status_type = status_type
-        self.clear_type = clear_type
 
     def get_clear_rank(self):
         self.clear_rank_list = []
@@ -372,19 +402,17 @@ class get_clear_rank_list:
         return self.clear_rank_list
 
 # 获取清词列表相关数据；
-class get_clear_keyword_list:
-    def __init__(self, start_time, end_time, genre_type=36, filter='offline', search_word=''):
+class get_clear_keyword_list(qimai_diy_var):
+    def __init__(self, start_time, end_time):
+        qimai_diy_var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
-        self.genre_type = genre_type
-        self.filter = filter
-        self.search_word = search_word
 
     def get_clear_keyword(self):
         self.clear_word_list = []
         page_num = 1
         while True:
-            url = 'https://api.qimai.cn/rank/clearWords?edate=%s&page=%s&genre=%s&sdate=%s&filter=%s&export_type=rank_clear_words&sort_field=beforeClearNum&sort_type=desc&search=%s' %(self.end_time, page_num, self.genre_type, self.start_time, self.filter, self.search_word)
+            url = 'https://api.qimai.cn/rank/clearWords?edate=%s&page=%s&genre=%s&sdate=%s&filter=%s&export_type=%s&sort_field=%s&sort_type=%s&search=%s' %(self.end_time, page_num, self.genre_type, self.start_time, self.filter, self.export_type, self.sort_field, self.sort_type, self.search_word)
             res = session.get(url, headers=headers)
             self.clear_word_list.append(res.json())
             page_num += 1
@@ -393,19 +421,17 @@ class get_clear_keyword_list:
         return self.clear_word_list
 
 # 获取下架产品列表相关数据；
-class get_app_offline_list:
-    def __init__(self, start_time, end_time, genre_type=36, option=4, search_word=''):
+class get_app_offline_list(qimai_diy_var):
+    def __init__(self, start_time, end_time):
+        qimai_diy_var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
-        self.genre_type = genre_type
-        self.option = option
-        self.search_word = search_word
 
     def get_app_offline(self):
         self.app_offline_list = []
         page_num = 1
         while True:
-            url = 'https://api.qimai.cn/rank/offline?date=%s_%s&country=cn&genre=%s&option=%s&search=%s&sdate=%s&edate=%s&page=%s' % (self.start_time, self.end_time, self.genre_type, self.option, self.search_word, self.start_time, self.end_time, page_num)
+            url = 'https://api.qimai.cn/rank/offline?date=%s_%s&country=%s&genre=%s&option=%s&search=%s&sdate=%s&edate=%s&page=%s' % (self.start_time, self.end_time, self.country, self.genre_type, self.option, self.search_word, self.start_time, self.end_time, page_num)
             res = session.get(url, headers=headers)
             self.app_offline_list.append(res.json())
             page_num += 1
